@@ -23,6 +23,7 @@
 #include <klocale.h>
 
 #include <element.h>
+#include <kunitconversion/converter.h>
 
 #include "prefs.h"
 
@@ -165,3 +166,20 @@ QString KalziumUtils::prettyUnit( const Element* el, ChemicalDataObject::BlueObe
     }
     return result;
 }
+
+
+void KalziumUtils::populateUnitCombobox(QComboBox *comboBox, const QList< int > &unitList)
+{
+    comboBox->clear();
+
+    QString unitString;
+
+    foreach( int unit, unitList) {
+        unitString = KUnitConversion::Converter().unit(unit).data()->description();
+        unitString.append(" (");
+        unitString.append(KUnitConversion::Converter().unit(unit).data()->symbol());
+        unitString.append(")");
+        comboBox->addItem( unitString, unit );
+    }
+
+}
\ No newline at end of file
